#!/bin/sh
echo 'name: pugs-DrIFT
version: 2.2.3.20130611
id: pugs-DrIFT-2.2.3.20130611-4db2cfdc83f10512e6428a78718918c6

license: BSD3
copyright:
maintainer: Audrey Tang <audreyt@audreyt.org>
stability:
homepage: http://pugscode.org/
package-url:
synopsis: DrIFT with pugs-specific rules.
description: DrIFT is a type sensitive preprocessor for Haskell. It extracts type declarations
             and directives from modules. The directives cause rules to be fired on the parsed
             type declarations, generating new code which is then appended to the bottom of the input
             file. The rules are expressed as Haskell code, and it is intended that the user can add new
             rules as required.
             DrIFT automates instance derivation for classes that aren'\''t supported by the standard compilers.
             In addition, instances can be produced in seperate modules to that containing the type declaration.
             This allows instances to be derived for a type after the original module has been compiled.
             As a bonus, simple utility functions can also be produced from a type.
category: Pugs
author: Noel Winstanley
pkgpath: devel/hs-pugs-DrIFT
exposed: True
exposed-modules: DrIFT.JSON DrIFT.Perl5 DrIFT.Perl6Class DrIFT.YAML
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20130611
library-dirs: /usr/local/lib/ghc/pugs-DrIFT-2.2.3.20130611
hs-libraries: HSpugs-DrIFT-2.2.3.20130611
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: HsSyck-0.50-f3b22abe56e30455b752ce443e50852f
         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
         old-time-1.1.0.1-8b10e3f99ed8611456aa344014a88da2
         pretty-1.1.1.0-2de27f83b2c1c65d629a564e9e01b27d
         random-1.0.1.1-e63672c93ea60d4fa26e4b5c7949f935
         stm-2.4.2-0f41fcf17f5bc067084394f47dbfe7cf
         utf8-string-0.3.8-123abdc63e716e348b66c892fc671d76
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20130611/html/pugs-DrIFT.haddock
haddock-html: /usr/local/share/doc/hs-pugs-DrIFT-2.2.3.20130611/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
